"""
sbfi-knime-utils: A utility package for KNIME workflows SBFI.

This package provides helper functions and utilities to streamline KNIME integration.
"""

__version__ = "1.2.0"
__author__ = "SBFI CoE Team"
__email__ = "sbfap_autobot@suntory.com"